@@ -1,4 +1,17 @@
 # ABSTRACT: 打包小说为TXT
+=pod
+
+=encoding utf8
+
+=head1 FUNCTION
+
+=head2 new 初始化
+
+   my $packer = Novel::Robot::Packer::TXT->new({
+	format_option => [ ], 
+   });
+
+=cut
 package Novel::Robot::Packer::TXT;
 
 use strict;
@@ -20,41 +33,41 @@ sub BUILD {
 
 sub open_packer {
     my ($self, $index) = @_;
-    $self->format_filename("$index->{writer}-$index->{book}.txt");
-    $self->{fh} = IO::File->new($self->{filename}, '>:utf8');
+    my $fname = $self->format_filename("$index->{writer}-$index->{book}.txt");
+    my $fh = IO::File->new($fname, '>:utf8');
 }
 
 sub format_before_index {
-    my ( $self, $index ) = @_;
+    my ( $self,$fh,  $index ) = @_;
     my $title = "$index->{writer}  《$index->{book}》 ";
-    $self->{fh}->print("$title\n\n");
+    $fh->print("$title\n\n");
 }
 
 sub format_index {
-    my ($self, $index) = @_;
+    my ($self,$fh, $index) = @_;
 
     my $num = $index->{chapter_num};
     my $r = $index->{chapter_info};
 
-    my @chap_list = map { "chap $_ ".($r->[$_]{title} || '') } (1 .. $num);
+    my @chap_list = map { "chap $_ ".($r->[$_-1]{title} || '') } (1 .. $num);
     my $toc = join("\n", @chap_list);
 
-    $self->{fh}->print("$toc\n\n");
+    $fh->print("$toc\n\n");
 }
 
 sub format_chapter {
-    my ( $self, $chap, $id) = @_;
+    my ( $self, $fh, $chap, $id) = @_;
     $id ||= $chap->{id};
 
     my $tree = HTML::TreeBuilder->new_from_content("chap $id : $chap->{title}<br>$chap->{content}");
     my $c = $self->{formatter}->format($tree);
 
-    $self->{fh}->print("$c\n\n");
+    $fh->print("$c\n\n");
 } ## end sub generate_chapter_url
 
 sub close_packer {
-    my ($self, $index) = @_;
-    $self->{fh}->close;
+    my ($self,$fh, $index) = @_;
+    $fh->close;
 }
 
 no Moo;
